@@ -112,7 +112,7 @@ class BookmarksExtension(gaupol.Extension):
         column.set_resizable(False)
         column.set_reorderable(True)
         column.set_visible(self._conf.show_column)
-        label = page.view.get_header_label(_("Bm."))
+        label = page.view.get_header_label(title=_("Bm."))
         label.set_tooltip_text(_("Bookmark"))
         column.set_widget(label)
         column.gaupol_id = "bookmark"
@@ -180,7 +180,7 @@ class BookmarksExtension(gaupol.Extension):
         """Initialize UI manager actions."""
         self._action_group.add_actions((
             ("show_bookmarks_menu", None, _("_Bookmarks")),
-            ("add_bookmark", Gtk.STOCK_ADD, _("_Add…"),
+            ("add_bookmark", None, _("_Add…"),
              "<Control>D", _("Add a bookmark for the current subtitle"),
              self._on_add_bookmark_activate),
             ("edit_bookmarks", None, _("_Edit Bookmarks"),
@@ -213,24 +213,18 @@ class BookmarksExtension(gaupol.Extension):
         self._conf = gaupol.conf.extensions.bookmarks
         self._search_entry = Gtk.Entry()
         self._side_container = Gtk.Alignment(xalign=0, yalign=0)
-        self._side_vbox = gaupol.util.new_vbox(spacing=6)
+        self._side_vbox = gaupol.util.new_vbox(spacing=0)
         self._tree_view = Gtk.TreeView()
         self._uim_id = None
 
     def _init_side_pane_widget(self):
         """Initialize the side pane widget."""
-        self._side_vbox.set_border_width(2)
-        hbox = gaupol.util.new_hbox(spacing=6)
-        label = Gtk.Label(label=_("Search:"))
-        gaupol.util.pack_start(hbox, label)
-        gaupol.util.pack_start_expand(hbox, self._search_entry)
-        gaupol.util.pack_start(self._side_vbox, hbox)
+        gaupol.util.pack_start(self._side_vbox, self._search_entry)
         scroller = Gtk.ScrolledWindow()
-        scroller.set_policy(*((Gtk.PolicyType.AUTOMATIC,) * 2))
+        scroller.set_policy(*((Gtk.PolicyType.AUTOMATIC,)*2))
         scroller.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
         scroller.add(self._tree_view)
         gaupol.util.pack_start_expand(self._side_vbox, scroller)
-        self._side_container.set_padding(0, 6, 2, 0)
         self._side_container.add(self._side_vbox)
         self._side_container.show_all()
 
@@ -249,7 +243,6 @@ class BookmarksExtension(gaupol.Extension):
         store_filter.set_visible_column(0)
         self._tree_view.set_model(store_filter)
         self._tree_view.set_headers_visible(False)
-        self._tree_view.set_rules_hint(True)
         self._tree_view.set_enable_search(False)
         selection = self._tree_view.get_selection()
         selection.set_mode(Gtk.SelectionMode.SINGLE)
@@ -278,6 +271,7 @@ class BookmarksExtension(gaupol.Extension):
         """Remove all data stored for `page`."""
         if page in self._bookmarks:
             del self._bookmarks[page]
+        self._update_tree_view()
 
     def _on_application_page_switched(self, application, page):
         """Update the side pane to show `page`'s bookmarks."""
@@ -396,6 +390,7 @@ class BookmarksExtension(gaupol.Extension):
         path = store.get_path(itr)
         row = store[path][1] - 1
         page = self.application.get_current_page()
+        if page is None: return
         col = page.view.get_focus()[1]
         page.view.set_focus(row, col)
         page.view.scroll_to_row(row)
@@ -451,7 +446,7 @@ class BookmarksExtension(gaupol.Extension):
 
     def setup(self, application):
         """Setup extension for use with `application`."""
-        options = {"show_column": True}
+        options = dict(show_column=True)
         gaupol.conf.register_extension("bookmarks", options)
         self._init_attributes(application)
         self._init_tree_view()
