@@ -96,7 +96,7 @@ class SidePane(aeidon.Observable):
         self._init_notebook(side_vbox)
         self._paned.show_all()
         child = self._paned.get_child1()
-        child.props.visible = self._conf.visible
+        child.set_visible(self._conf.visible)
 
     def _init_header(self, side_vbox):
         """Initialize the side pane button header."""
@@ -119,7 +119,7 @@ class SidePane(aeidon.Observable):
         gaupol.util.pack_start_expand(header_hbox, Gtk.Label())
         close_button = Gtk.Button()
         image = gaupol.util.get_icon_image("window-close-symbolic",
-                                           Gtk.STOCK_CLOSE,
+                                           "window-close",
                                            Gtk.IconSize.MENU)
 
         close_button.add(image)
@@ -140,10 +140,12 @@ class SidePane(aeidon.Observable):
         """Initialize the horizontal pane container."""
         main_vbox = self.application.window.get_children()[0]
         main_notebook = main_vbox.get_children()[2]
-        main_notebook.props.expand = True
+        main_notebook.set_hexpand(True)
+        main_notebook.set_vexpand(True)
         self._paned.pack1(side_vbox, resize=False, shrink=False)
         main_notebook_vbox = gaupol.util.new_vbox(spacing=0)
-        main_notebook.reparent(main_notebook_vbox)
+        main_vbox.remove(main_notebook)
+        main_notebook_vbox.add(main_notebook)
         self._paned.pack2(main_notebook_vbox, resize=True, shrink=False)
         gaupol.util.pack_start_expand(main_vbox, self._paned)
         main_vbox.reorder_child(self._paned, 2)
@@ -201,6 +203,7 @@ class SidePane(aeidon.Observable):
         spaces = (Gdk.KEY_space, Gdk.KEY_KP_Space)
         enters = (Gdk.KEY_Return, Gdk.KEY_KP_Enter)
         if not event.keyval in (spaces + enters): return False
+        event.button = 1
         self._show_header_menu(event)
         return True
 
@@ -227,11 +230,13 @@ class SidePane(aeidon.Observable):
         if child is not None:
             self._conf.page = child.gaupol_side_pane_extension_name
         child = self._paned.get_child1()
-        self._conf.visible = child.props.visible
+        self._conf.visible = child.get_visible()
         main_vbox = self.application.window.get_children()[0]
-        main_notebook = self._paned.get_child2().get_children()[0]
+        main_notebook_vbox = self._paned.get_child2()
+        main_notebook = main_notebook_vbox.get_children()[0]
         main_vbox.remove(self._paned)
-        main_notebook.reparent(main_vbox)
+        main_notebook_vbox.remove(main_notebook)
+        main_vbox.add(main_notebook)
         main_vbox.reorder_child(main_notebook, 2)
         self._paned.destroy()
 
@@ -254,6 +259,7 @@ class SidePane(aeidon.Observable):
 
     def _show_header_menu(self, event):
         """Show a menu listing all side pane pages."""
+        # XXX: Since GTK+ 3.14 this no longer seems to work.
         menu = Gtk.Menu()
         for i in range(self._notebook.get_n_pages()):
             child = self._notebook.get_nth_page(i)
@@ -300,7 +306,7 @@ class SidePaneExtension(gaupol.Extension):
 
     def setup(self, application):
         """Setup extension for use with `application`."""
-        options = {"width": 200, "page": "", "visible": True}
+        options = dict(width=200, page="", visible=True)
         gaupol.conf.register_extension("side_pane", options)
         self._conf = gaupol.conf.extensions.side_pane
         application.side_pane = SidePane(application)
