@@ -39,9 +39,9 @@ class Action(Gtk.Action):
 
     :ivar accelerator: Accelerator string or ``None``
 
-       :attr:`accelerator` defines a string in the format understood by
-       :func:`Gtk.accelerator_parse`, ``None`` to use the stock accelerator
-       or unset to use a blank string, i.e. undefined.
+       :attr:`accelerator` defines a string in the format understood
+       by :func:`Gtk.accelerator_parse`, leave undefined to fall back
+       on a blank string, i.e. no accelerator.
 
     :ivar action_group: Name of action group to place action into
 
@@ -93,7 +93,7 @@ class Action(Gtk.Action):
     def finalize(self, application):
         """Connect action to widgets and methods of `application`."""
         self.widgets = tuple(getattr(application, x) for x in self.widgets)
-        callback = "_on_{}_activate".format(self.props.name)
+        callback = "_on_{}_activate".format(self.get_name())
         self.connect("activate", getattr(application, callback))
 
     def set_sensitive(self, sensitive):
@@ -118,7 +118,7 @@ class MenuAction(Action):
     def finalize(self, application):
         """Connect action to widgets and methods of `application`."""
         self.widgets = tuple(getattr(application, x) for x in self.widgets)
-        callback = "_on_{}_activate".format(self.props.name)
+        callback = "_on_{}_activate".format(self.get_name())
         if hasattr(application, callback):
             self.connect("activate", getattr(application, callback))
 
@@ -152,15 +152,15 @@ class RecentAction(Gtk.RecentAction, Action):
         recent_filter.add_mime_type("text/x-subviewer")
         self.add_filter(recent_filter)
         self.set_filter(recent_filter)
-        self.set_limit(gaupol.conf.file.max_recent)
+        self.set_limit(10)
 
     def finalize(self, application):
         """Connect action to widgets of `application`."""
         self.widgets = tuple(getattr(application, x) for x in self.widgets)
-        callback = "_on_{}_activate".format(self.props.name)
+        callback = "_on_{}_activate".format(self.get_name())
         if hasattr(application, callback):
             self.connect("activate", getattr(application, callback))
-        callback = "_on_{}_item_activated".format(self.props.name)
+        callback = "_on_{}_item_activated".format(self.get_name())
         self.connect("item-activated", getattr(application, callback))
 
 
@@ -175,7 +175,7 @@ class ToggleAction(Gtk.ToggleAction, Action):
     def finalize(self, application):
         """Connect action to widgets and methods of `application`."""
         self.widgets = tuple(getattr(application, x) for x in self.widgets)
-        callback = "_on_{}_toggled".format(self.props.name)
+        callback = "_on_{}_toggled".format(self.get_name())
         self.connect("toggled", getattr(application, callback))
 
 
@@ -206,5 +206,5 @@ class RadioAction(Gtk.RadioAction, Action):
         """Connect action to widgets and methods of `application`."""
         self.widgets = tuple(getattr(application, x) for x in self.widgets)
         if self.__class__.__name__ == self.group:
-            callback = "_on_{}_changed".format(self.props.name)
+            callback = "_on_{}_changed".format(self.get_name())
             self.connect("changed", getattr(application, callback))
