@@ -21,8 +21,6 @@ import aeidon
 import gaupol
 _ = aeidon.i18n._
 
-from gi.repository import Gtk
-
 
 class LoadVideoAction(gaupol.Action):
 
@@ -31,8 +29,8 @@ class LoadVideoAction(gaupol.Action):
     def __init__(self):
         """Initialize a :class:`LoadVideoAction` instance."""
         gaupol.Action.__init__(self, "load_video")
-        self.props.label = _("_Load Video…")
-        self.props.tooltip = _("Load a video file")
+        self.set_label(_("_Load Video…"))
+        self.set_tooltip(_("Load a video file"))
         self.accelerator = "<Control>L"
         self.action_group = "main-safe"
 
@@ -49,9 +47,9 @@ class PlayPauseAction(gaupol.Action):
     def __init__(self):
         """Initialize a :class:`PlayPauseAction` instance."""
         gaupol.Action.__init__(self, "play_pause")
-        self.props.label = _("_Play/Pause")
-        self.props.stock_id = Gtk.STOCK_MEDIA_PLAY
-        self.props.tooltip = _("Play or pause video")
+        self.set_icon_name("media-playback-start")
+        self.set_label(_("_Play/Pause"))
+        self.set_tooltip(_("Play or pause video"))
         self.accelerator = "P"
         self.action_group = "main-unsafe"
 
@@ -67,8 +65,8 @@ class PlaySelectionAction(gaupol.Action):
     def __init__(self):
         """Initialize a :class:`PlaySelectionAction`."""
         gaupol.Action.__init__(self, "play_selection")
-        self.props.label = _("Play _Selection")
-        self.props.tooltip = _("Play the selected subtitles")
+        self.set_label(_("Play _Selection"))
+        self.set_tooltip(_("Play the selected subtitles"))
         self.accelerator = "O"
         self.action_group = "main-unsafe"
 
@@ -85,9 +83,9 @@ class SeekBackwardAction(gaupol.Action):
     def __init__(self):
         """Initialize a :class:`SeekBackwardAction` instance."""
         gaupol.Action.__init__(self, "seek_backward")
-        self.props.label = _("Seek _Backward")
-        self.props.stock_id = Gtk.STOCK_MEDIA_REWIND
-        self.props.tooltip = _("Seek backward")
+        self.set_icon_name("media-seek-backward")
+        self.set_label(_("Seek _Backward"))
+        self.set_tooltip(_("Seek backward"))
         self.accelerator = "<Shift><Ctrl>Left"
         self.action_group = "main-unsafe"
 
@@ -103,9 +101,9 @@ class SeekForwardAction(gaupol.Action):
     def __init__(self):
         """Initialize a :class:`SeekForwardAction` instance."""
         gaupol.Action.__init__(self, "seek_forward")
-        self.props.label = _("Seek _Forward")
-        self.props.stock_id = Gtk.STOCK_MEDIA_FORWARD
-        self.props.tooltip = _("Seek forward")
+        self.set_icon_name("media-seek-forward")
+        self.set_label(_("Seek _Forward"))
+        self.set_tooltip(_("Seek forward"))
         self.accelerator = "<Shift><Ctrl>Right"
         self.action_group = "main-unsafe"
 
@@ -121,9 +119,9 @@ class SeekNextAction(gaupol.Action):
     def __init__(self):
         """Initialize a :class:`SeekNextAction` instance."""
         gaupol.Action.__init__(self, "seek_next")
-        self.props.label = _("Seek _Next")
-        self.props.stock_id = Gtk.STOCK_MEDIA_NEXT
-        self.props.tooltip = _("Seek to the start of the next subtitle")
+        self.set_icon_name("media-skip-forward")
+        self.set_label(_("Seek _Next"))
+        self.set_tooltip(_("Seek to the start of the next subtitle"))
         self.accelerator = "<Ctrl>Right"
         self.action_group = "main-unsafe"
 
@@ -139,9 +137,9 @@ class SeekPreviousAction(gaupol.Action):
     def __init__(self):
         """Initialize a :class:`SeekPreviousAction` instance."""
         gaupol.Action.__init__(self, "seek_previous")
-        self.props.label = _("Seek _Previous")
-        self.props.stock_id = Gtk.STOCK_MEDIA_PREVIOUS
-        self.props.tooltip = _("Seek to the start of the previous subtitle")
+        self.set_icon_name("media-skip-backward")
+        self.set_label(_("Seek _Previous"))
+        self.set_tooltip(_("Seek to the start of the previous subtitle"))
         self.accelerator = "<Ctrl>Left"
         self.action_group = "main-unsafe"
 
@@ -157,8 +155,8 @@ class SeekSelectionEndAction(gaupol.Action):
     def __init__(self):
         """Initialize a :class:`SeekSelectionEnd` instance."""
         gaupol.Action.__init__(self, "seek_selection_end")
-        self.props.label = _("See_k Selection End")
-        self.props.tooltip = _("Seek the end of selection")
+        self.set_label(_("See_k Selection End"))
+        self.set_tooltip(_("Seek the end of selection"))
         self.accelerator = "<Ctrl>Down"
         self.action_group = "main-unsafe"
 
@@ -175,8 +173,8 @@ class SeekSelectionStartAction(gaupol.Action):
     def __init__(self):
         """Initialize a :class:`SeekSelectionStart` instance."""
         gaupol.Action.__init__(self, "seek_selection_start")
-        self.props.label = _("S_eek Selection Start")
-        self.props.tooltip = _("Seek the start of selection")
+        self.set_label(_("S_eek Selection Start"))
+        self.set_tooltip(_("Seek the start of selection"))
         self.accelerator = "<Ctrl>Up"
         self.action_group = "main-unsafe"
 
