@@ -176,20 +176,23 @@ class UpdateAgent(aeidon.Delegate):
         if page is None: return
         if page.project.can_undo():
             action = self.get_action("undo_action")
-            action.props.tooltip = _('Undo "{}"').format(
-                page.project.undoables[0].description)
+            action.set_tooltip(_('Undo "{}"').format(
+                page.project.undoables[0].description))
         if page.project.can_redo():
             action = self.get_action("redo_action")
-            action.props.tooltip = _('Redo "{}"').format(
-                page.project.redoables[0].description)
+            action.set_tooltip(_('Redo "{}"').format(
+                page.project.redoables[0].description))
 
     def _update_widgets(self, page):
         """Update states of all widgets for `page`."""
         if page is None: return self._disable_widgets()
         self.window.set_title(page.tab_label.get_text())
+        tabs = len(self.pages) > 1 and not self.player_box.get_visible()
+        self.notebook.set_show_tabs(tabs)
+        self.notebook_separator.set_visible(not tabs)
         self.get_mode_action(page.edit_mode).set_active(True)
         self.get_framerate_action(page.project.framerate).set_active(True)
         for field in gaupol.fields:
             col = getattr(page.view.columns, field.name)
-            visible = page.view.get_column(col).props.visible
+            visible = page.view.get_column(col).get_visible()
             self.get_column_action(field).set_active(visible)
