@@ -81,7 +81,11 @@ class BuilderPage(TextAssistantPage):
         self._builder.add_from_file(ui_file_path)
         self._builder.connect_signals(self)
         self._set_attributes(self._widgets)
-        self._builder.get_object("main_container").reparent(self)
+        container = self._builder.get_object("main_container")
+        window = container.get_parent()
+        window.remove(container)
+        self.add(container)
+        gaupol.util.idle_add(window.destroy)
 
     def _set_attributes(self, widgets):
         """Assign all names in `widgets` as attributes of `self`."""
@@ -130,8 +134,8 @@ class IntroductionPage(BuilderPage):
         """Initalize the columns target combo box."""
         store = Gtk.ListStore(str)
         self._columns_combo.set_model(store)
-        store.append((_("Correct texts in main text column"),))
-        store.append((_("Correct texts in translation text column"),))
+        store.append((_("Correct texts in the text column"),))
+        store.append((_("Correct texts in the translation column"),))
         renderer = Gtk.CellRendererText()
         self._columns_combo.pack_start(renderer, expand=True)
         self._columns_combo.add_attribute(renderer, "text", 0)
@@ -176,7 +180,7 @@ class IntroductionPage(BuilderPage):
                  gaupol.targets.CURRENT: 1,
                  gaupol.targets.ALL: 2}[target]
 
-        self._subtitles_combo.set_active(target)
+        self._subtitles_combo.set_active(index)
 
     def _on_columns_combo_changed(self, *args):
         """Save the selected field."""
@@ -190,7 +194,7 @@ class IntroductionPage(BuilderPage):
         """Toggle and save task check button value."""
         store = self._tree_view.get_model()
         store[path][1] = not store[path][1]
-        store[path][0].props.visible = store[path][1]
+        store[path][0].set_visible(store[path][1])
         pages = [x.handle for x in self.get_selected_pages()]
         gaupol.conf.text_assistant.pages = pages
 
@@ -203,7 +207,7 @@ class IntroductionPage(BuilderPage):
             title = GLib.markup_escape_text(page.title)
             description = GLib.markup_escape_text(page.description)
             markup = "<b>{}</b>\n{}".format(title, description)
-            page.props.visible = (page.handle in pages)
+            page.set_visible(page.handle in pages)
             store.append((page, page.handle in pages, markup))
         self._tree_view.get_selection().unselect_all()
 
@@ -241,7 +245,7 @@ class LocalePage(BuilderPage):
 
     def _get_country(self):
         """Return the selected country or ``None``."""
-        if not self._country_combo.props.sensitive: return None
+        if not self._country_combo.get_sensitive(): return None
         index = self._country_combo.get_active()
         if index < 0: return None
         store = self._country_combo.get_model()
@@ -250,7 +254,7 @@ class LocalePage(BuilderPage):
 
     def _get_language(self):
         """Return the selected language or ``None``."""
-        if not self._language_combo.props.sensitive: return None
+        if not self._language_combo.get_sensitive(): return None
         index = self._language_combo.get_active()
         if index < 0: return None
         store = self._language_combo.get_model()
@@ -259,7 +263,7 @@ class LocalePage(BuilderPage):
 
     def _get_script(self):
         """Return the selected script or ``None``."""
-        if not self._script_combo.props.sensitive: return None
+        if not self._script_combo.get_sensitive(): return None
         index = self._script_combo.get_active()
         if index < 0: return None
         store = self._script_combo.get_model()
@@ -577,11 +581,10 @@ class JoinSplitWordsPage(BuilderPage):
 
     def _init_values(self):
         """Initialize default values for widgets."""
-        label = self._language_button.get_label()
+        language = gaupol.conf.spell_check.language
         with aeidon.util.silent(LookupError):
-            language = gaupol.conf.spell_check.language
-            label = aeidon.locales.code_to_name(language)
-        self._set_language_button_label(label)
+            language = aeidon.locales.code_to_name(language)
+        self._language_button.set_label(language)
         self._join_check.set_active(gaupol.conf.join_split_words.join)
         self._split_check.set_active(gaupol.conf.join_split_words.split)
 
@@ -595,22 +598,15 @@ class JoinSplitWordsPage(BuilderPage):
         dialog = gaupol.LanguageDialog(self.assistant, False)
         gaupol.util.set_cursor_normal(self.assistant)
         gaupol.util.flash_dialog(dialog)
-        label = self._language_button.get_label()
+        language = gaupol.conf.spell_check.language
         with aeidon.util.silent(LookupError):
-            language = gaupol.conf.spell_check.language
-            label = aeidon.locales.code_to_name(language)
-        self._set_language_button_label(label)
+            language = aeidon.locales.code_to_name(language)
+        self._language_button.set_label(language)
 
     def _on_split_check_toggled(self, check_button, *args):
         """Save value of split option."""
         gaupol.conf.join_split_words.split = check_button.get_active()
 
-    def _set_language_button_label(self, text):
-        """Set `text` as the language button label."""
-        box = self._language_button.get_child()
-        label = box.get_children()[0]
-        label.set_text(text)
-
     def _show_error_dialog(self, message):
         """Show an error dialog after failing to load dictionary."""
         name = gaupol.conf.spell_check.language
@@ -618,7 +614,7 @@ class JoinSplitWordsPage(BuilderPage):
             name = aeidon.locales.code_to_name(name)
         title = _('Failed to load dictionary for language "{}"').format(name)
         dialog = gaupol.ErrorDialog(self.get_parent(), title, message)
-        dialog.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
+        dialog.add_button(_("_OK"), Gtk.ResponseType.OK)
         dialog.set_default_response(Gtk.ResponseType.OK)
         gaupol.util.flash_dialog(dialog)
 
@@ -862,7 +858,7 @@ class ConfirmationPage(BuilderPage):
         renderer.props.ypad = 4
         column = Gtk.TreeViewColumn(title, renderer, text=index)
         column.set_resizable(True)
-        column.props.expand = True
+        column.set_expand(True)
         self._tree_view.append_column(column)
 
     def _can_preview(self):
@@ -896,7 +892,6 @@ class ConfirmationPage(BuilderPage):
         # page, index, accept, original text, new text
         store = Gtk.ListStore(object, int, bool, str, str)
         self._tree_view.set_model(store)
-        self._tree_view.set_rules_hint(False)
         selection = self._tree_view.get_selection()
         selection.set_mode(Gtk.SelectionMode.SINGLE)
         selection.connect("changed", self._on_tree_view_selection_changed)
@@ -1021,7 +1016,7 @@ class TextAssistant(Gtk.Assistant):
             self.add_page(page)
         def on_notify_visible(page, prop, pages):
             for page in pages[1:]:
-                page.props.visible = pages[0].props.visible
+                page.set_visible(pages[0].get_visible())
         pages[0].connect("notify::visible", on_notify_visible, pages)
 
     def _copy_project(self, project):
