@@ -20,6 +20,7 @@
 import aeidon
 import gaupol
 import os
+_ = aeidon.i18n._
 
 from gi.repository import GObject
 from gi.repository import Gtk
@@ -45,8 +46,8 @@ class OpenDialog(Gtk.FileChooserDialog, gaupol.FileDialog):
         self.set_title(title)
         self.set_transient_for(parent)
         self.set_action(Gtk.FileChooserAction.OPEN)
-        self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
-        self.add_button(Gtk.STOCK_OPEN, Gtk.ResponseType.OK)
+        self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
+        self.add_button(_("_Open"), Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.OK)
         self.connect("response", self._on_response)
 
@@ -74,7 +75,9 @@ class OpenDialog(Gtk.FileChooserDialog, gaupol.FileDialog):
             widget = builder.get_object(name)
             setattr(self, "_{}".format(name), widget)
         vbox = gaupol.util.new_vbox(spacing=0)
-        builder.get_object("main_vbox").reparent(vbox)
+        main_vbox = builder.get_object("main_vbox")
+        main_vbox.get_parent().remove(main_vbox)
+        vbox.add(main_vbox)
         vbox.show_all()
         self.set_extra_widget(vbox)
 
@@ -85,8 +88,8 @@ class OpenDialog(Gtk.FileChooserDialog, gaupol.FileDialog):
             self.set_current_folder(gaupol.conf.file.directory)
         self.set_encoding(gaupol.conf.file.encoding)
         self._align_combo.set_active(gaupol.conf.file.align_method)
-        self._align_combo.props.visible = (doc == aeidon.documents.TRAN)
-        self._align_label.props.visible = (doc == aeidon.documents.TRAN)
+        self._align_combo.set_visible(doc == aeidon.documents.TRAN)
+        self._align_label.set_visible(doc == aeidon.documents.TRAN)
 
     def _on_response(self, dialog, response):
         """Save default values for widgets."""
