@@ -37,7 +37,7 @@ class VideoDialog(Gtk.FileChooserDialog):
         self.set_title(title)
         self.set_transient_for(parent)
         self.set_action(Gtk.FileChooserAction.OPEN)
-        self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
+        self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
         self.add_button(button_label, Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.OK)
         self._init_filters()
@@ -52,8 +52,6 @@ class VideoDialog(Gtk.FileChooserDialog):
         video_filter.add_mime_type("video/*")
         video_filter.set_name(_("Video files"))
         self.add_filter(video_filter)
-        if sys.platform == "win32":
-            # Mimetype detection seems unreliable on Windows.
-            self.set_filter(all_filter)
-        else:
-            self.set_filter(video_filter)
+        # Mimetype detection seems unreliable on Windows.
+        self.set_filter(all_filter if sys.platform == "win32"
+                        else video_filter)
