@@ -124,7 +124,7 @@ def connect_text_view(text_view):
     layout.set_text("8", -1)
     width = layout.get_pixel_size()[0]
     text_view.set_border_window_size(Gtk.TextWindowType.RIGHT, width+6)
-    handler_id = text_view.connect("draw", _on_text_view_draw)
+    handler_id = text_view.connect_after("draw", _on_text_view_draw)
     text_view.gaupol_ruler_handler_id = handler_id
     return handler_id
 
