@@ -84,8 +84,8 @@ def get_content_size(widget):
 def get_font():
     """Return custom font or blank string."""
     return (gaupol.conf.editor.custom_font if
-            (gaupol.conf.editor.use_custom_font and
-             gaupol.conf.editor.custom_font) else "")
+            gaupol.conf.editor.use_custom_font and
+            gaupol.conf.editor.custom_font else "")
 
 def get_gst_version():
     """Return :mod:`Gst` version number as string or ``None``."""
@@ -95,25 +95,12 @@ def get_gst_version():
     except Exception:
         return None
 
-def get_gtkspell_version():
-    """
-    Return :mod:`GtkSpell` version number as string or ``None``.
-
-    Please try not to use this.
-    """
-    try:
-        from gi.repository import GtkSpell
-        # XXX: Not public!?
-        return GtkSpell._version
-    except Exception:
-        return None
-
-def get_icon_image(name, stock, size):
-    """Return icon image from name in theme or stock as fallback."""
+def get_icon_image(name, fallback, size):
+    """Return icon image from `name` or `fallback` in theme."""
     theme = Gtk.IconTheme.get_default()
     if theme.has_icon(name):
         return Gtk.Image(icon_name=name, icon_size=size)
-    return Gtk.Image.new_from_stock(stock, size)
+    return Gtk.Image(icon_name=name, icon_size=size)
 
 def get_preview_command():
     """Return command to use for lauching video player."""
@@ -133,8 +120,8 @@ def get_text_view_size(text_view, font=None):
         set_widget_font(label, font)
     label.show()
     return (label.get_preferred_width()[1]
-            + text_view.props.left_margin
-            + text_view.props.right_margin,
+            + text_view.get_left_margin()
+            + text_view.get_right_margin(),
             label.get_preferred_height()[1])
 
 def get_tree_view_size(tree_view):
@@ -150,12 +137,6 @@ def get_tree_view_size(tree_view):
 @aeidon.deco.once
 def get_zebra_color(tree_view):
     """Return background color to use for tree view zebra-stripes."""
-    # Gtk.TreeView.set_rules_hint does not actually always produce
-    # zebra-stripes since some GTK+ theme authors have chosen to
-    # not allow them. To work around this, we can calculate
-    # the colors theme-independently as a weighted mean of normal
-    # background and foreground colors and set those using
-    # Gtk.TreeViewColumn.set_cell_data_func.
     style = tree_view.get_style_context()
     fg = style.get_color(Gtk.StateFlags.NORMAL)
     bg = style.get_background_color(Gtk.StateFlags.NORMAL)
@@ -175,33 +156,29 @@ def gst_available():
     """
     try:
         from gi.repository import Gst
-        if not Gst.ElementFactory.find("playbin"):
-            print("GStreamer found, but playbin missing.",
-                  "Try installing gst-plugins-base.",
-                  file=sys.stderr)
-
-            raise Exception
-        if not Gst.ElementFactory.find("textoverlay"):
-            print("GStreamer found, but textoverlay missing.",
-                  "Try installing gst-plugins-base.",
-                  file=sys.stderr)
-
-            raise Exception
-        if not Gst.ElementFactory.find("timeoverlay"):
-            print("GStreamer found, but timeoverlay missing.",
-                  "Try installing gst-plugins-base.",
-                  file=sys.stderr)
-
-            raise Exception
-        if not Gst.ElementFactory.find("autovideosink"):
-            print("GStreamer found, but autovideosink missing.",
-                  "Try installing gst-plugins-good.",
-                  file=sys.stderr)
-
-            raise Exception
-        return True
     except Exception:
         return False
+    if not Gst.ElementFactory.find("playbin"):
+        print("GStreamer found, but playbin missing.",
+              "Try installing gst-plugins-base.",
+              file=sys.stderr)
+        return False
+    if not Gst.ElementFactory.find("textoverlay"):
+        print("GStreamer found, but textoverlay missing.",
+              "Try installing gst-plugins-base.",
+              file=sys.stderr)
+        return False
+    if not Gst.ElementFactory.find("timeoverlay"):
+        print("GStreamer found, but timeoverlay missing.",
+              "Try installing gst-plugins-base.",
+              file=sys.stderr)
+        return False
+    if not Gst.ElementFactory.find("autovideosink"):
+        print("GStreamer found, but autovideosink missing.",
+              "Try installing gst-plugins-good.",
+              file=sys.stderr)
+        return False
+    return True
 
 @aeidon.deco.once
 def gtkspell_available():
@@ -224,6 +201,17 @@ def hex_to_rgba(string):
         raise ValueError("Parsing string {} failed".format(repr(string)))
     return rgba
 
+def idle_add(function, *args, **kwargs):
+    """
+    Call `function` with `args` and `kwargs` when idle.
+
+    Return integer ID of the event source from :func:`GLib.idle_add`.
+    """
+    def call_function(*args, **kwargs):
+        function(*args, **kwargs)
+        return False # to not be called again.
+    return GLib.idle_add(call_function, *args, **kwargs)
+
 def install_module(name, obj):
     """
     Install `obj`'s module into the :mod:`gaupol` namespace.
@@ -366,15 +354,20 @@ def separate_combo(store, itr, data=None):
 
 def set_cursor_busy(window):
     """Set mouse pointer busy when above window."""
+    cursor = window.get_window().get_cursor()
+    if (cursor is not None and cursor.get_cursor_type() ==
+        Gdk.CursorType.WATCH): return
     cursor = Gdk.Cursor(cursor_type=Gdk.CursorType.WATCH)
     window.get_window().set_cursor(cursor)
     iterate_main()
 
 def set_cursor_normal(window):
     """Set mouse pointer normal when above window."""
+    cursor = window.get_window().get_cursor()
+    if (cursor is not None and cursor.get_cursor_type() ==
+        Gdk.CursorType.LEFT_PTR): return
     cursor = Gdk.Cursor(cursor_type=Gdk.CursorType.LEFT_PTR)
     window.get_window().set_cursor(cursor)
-    iterate_main()
 
 def set_widget_font(widget, font):
     """Use `font` for `widget`."""
